==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiPage/InlineParser.pm <==
#
# WiKicker
#
#  InlineParser.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: InlineParser.pm,v 1.8 2004/05/29 02:58:29 naney Exp $
#
#
package WiKicker::WikiPage::InlineParser;

use strict;
use Carp;
use WiKicker::WikiPage::TextNode;
use WiKicker::WikiPage::EmphasisNode;
use WiKicker::WikiPage::InlineBlockNode;
use WiKicker::WikiPage::BracketNameParser;
use WiKicker::WikiPage::VerbatimNode;

use vars qw($uric $wiki_fragment_char $wiki_name_pat $bracket_name_pat $uri_pat $swrn_pat $wiki_fragment_pat $emphasis_pat $verbatim_pat $block_pat);
BEGIN {
$uric = '(?:[!$\x26-\x3b=\x3f-\x5a_\x61-\x7a~]|%[0-9a-zA-Z]{2})';
$wiki_fragment_char = '(?:[^\x20<>\#%"{}|\\^[\]`])';
$wiki_name_pat = "(\\b[A-Z][a-z]+(?:[A-Z][a-z]+)+(?:(?:/[A-Z][a-z]+(?:[A-Z][a-z]+)+)*)\\b(?:\\#$wiki_fragment_char+)?)";
$bracket_name_pat = '(\[\[(?:[^]]|(?:\\.)|(?:\][^]]))*\]\])';
$uri_pat = '((?:http|https|image|mailto|ftp|file|urn):(?:[^\x00-\x1f\x7f\x20<>\#"{}|\\^[\]`]+)(?:\#' . $uric . '*)?)';
$swrn_pat = '((?:ISBN:?[0-9](?:-?[0-9]){8}(?:-?[0-9xX]))|(?:ASIN:?[0-9a-zA-Z]+)|(?:(?:rfc|RFC)\d+))';
#$wiki_fragment_pat = "(\\#$wiki_fragment_char+)";
$emphasis_pat = "(''.*?'')";
$verbatim_pat = "(====.*?====)";
$block_pat = "({{.*?}})";
}

sub new {
  my ($class, %param) = @_;

  croak "no wri_factory" unless defined $param{wri_factory};

  my $self = bless {wri_factory => $param{wri_factory}}, $class;

  return $self;
}

sub parse {
  my ($self, $line) = @_;

  my @result;


  my $length = 0;
  while ($line =~
           m/\G([\x00-\xFF]*?)                   #skip
             (
                $wiki_name_pat
              | $bracket_name_pat
              | $uri_pat
              #| $wiki_fragment_pat
              | $emphasis_pat
              | $swrn_pat
              | $verbatim_pat
              | $block_pat
             )
         /ogx) {

    my $skip = $1;
    my $wiki_name = $3;
    my $bracket_name = $4;
    my $uri = $5;
    #my $wiki_fragment = $6;
    my $emphasis = $6;
    my $swrn = $7;
    my $verbatim = $8;
    my $block = $9;

#    if ($skip) {
    if ($skip ne '') {
      $length += length($skip);
      push(@result, WiKicker::WikiPage::TextNode->new($skip));
    }
    if ($wiki_name) {
      $length += length($wiki_name);
      push(@result, WiKicker::WikiPage::WriNode->new($wiki_name, $wiki_name, $self->{wri_factory}));
    }
    elsif ($bracket_name) {
      $length += length($bracket_name);
      push(@result, WiKicker::WikiPage::BracketNameParser->new(wri_factory => $self->{wri_factory})->parse($bracket_name));
    }
    elsif ($emphasis) {
      #$length += length($emphasis);
      #$emphasis =~ s/^''(.*)''$/$1/;
      my $em_length = length($emphasis);
      $length += $em_length;
      $emphasis = substr($emphasis, 2, $em_length - 4);
      my $emphasis_node = WiKicker::WikiPage::EmphasisNode->new;
      $emphasis_node->add(WiKicker::WikiPage::InlineParser->new(wri_factory => $self->{wri_factory})->parse($emphasis));
      push(@result, $emphasis_node);
    }
    elsif ($uri) {
      $length += length($uri);
      push(@result, WiKicker::WikiPage::WriNode->new($uri, $uri, $self->{wri_factory}));
    }
#     elsif ($wiki_fragment) {
#       $length += length($wiki_fragment);
#       push(@result, WiKicker::WikiPage::WriNode->new($wiki_fragment));
#     }
    elsif ($verbatim) {
      $length += length($verbatim);
      my $verbatim_text = $verbatim;
      $verbatim_text =~ s/^====(.*)====$/$1/;
      my $verbatim_node = WiKicker::WikiPage::VerbatimNode->new($verbatim, $verbatim_text);
      push(@result, $verbatim_node);
    }
    elsif ($swrn) {
      $length += length($swrn);
      push(@result, WiKicker::WikiPage::WriNode->new($swrn, $swrn, $self->{wri_factory}));
    }
    elsif ($block) {
      $length += length($block);
      $block =~ s/^{{(.*)}}$/$1/;
      my $scheme = '';
      if ($block =~ /^([^:]+):(.*)$/) {
        $scheme = $1;
        $block = $2;
      }
      my $block_node = WiKicker::WikiPage::InlineBlockNode->new($scheme);
      $block_node->add(WiKicker::WikiPage::InlineParser->new(wri_factory => $self->{wri_factory})->parse($block));
      push(@result, $block_node);
    }
  }
  if (length($line) > $length) {
    push(@result, WiKicker::WikiPage::TextNode->new(substr($line, $length)));
  }
  return @result;
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiPage/InlineParser.pm <==
#
# WiKicker
#
#  InlineParser.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: InlineParser.pm,v 1.11 2004/07/24 11:27:52 naney Exp $
#
#
package WiKicker::WikiPage::InlineParser;

use strict;
use Carp;
use WiKicker::WikiPage::TextNode;
use WiKicker::WikiPage::EmphasisNode;
use WiKicker::WikiPage::InlineBlockNode;
use WiKicker::WikiPage::BracketNameParser;
use WiKicker::WikiPage::VerbatimNode;

use vars qw($uric $wiki_fragment_char $wiki_name_pat $bracket_name_pat $uri_pat $swrn_pat $wiki_fragment_pat $emphasis_pat $verbatim_pat $block_pat);
BEGIN {
$uric = '(?:[!$\x26-\x3b=\x3f-\x5a_\x61-\x7a~]|%[0-9a-zA-Z]{2})';
$wiki_fragment_char = '(?:[^\x20<>\#%"{}|\\^[\]`])';
$wiki_name_pat = "(\\b[A-Z][a-z]+(?:[A-Z][a-z]+)+(?:(?:/[A-Z][a-z]+(?:[A-Z][a-z]+)+)*)\\b(?:\\#$wiki_fragment_char+)?)";
$bracket_name_pat = '(\[\[(?:[^]]|(?:\\.)|(?:\][^]]))*\]\])';
#$uri_pat = '((?:http|https|image|mailto|ftp|file|urn):(?:[^\x00-\x1f\x7f\x20<>\#"{}|\\^[\]`]+)(?:\#' . $uric . '*)?)';
$uri_pat = '((?:http|https|image|mailto|ftp|file|urn):' . $uric . '+(?:\#' . $uric . '*)?)';
$swrn_pat = '((?:ISBN:?[0-9](?:-?[0-9]){8}(?:-?[0-9xX]))|(?:ASIN:?[0-9a-zA-Z]+)|(?:(?:rfc|RFC)\d+))';
#$wiki_fragment_pat = "(\\#$wiki_fragment_char+)";
$emphasis_pat = "(''.*?'')";
$verbatim_pat = "(====.*?====)";
$block_pat = "({{.*?}})";
}

sub new {
  my ($class, %param) = @_;

  croak 'no wri_factory' unless defined $param{wri_factory};

  my $self = bless {wri_factory => $param{wri_factory}}, $class;

  return $self;
}

sub parse {
  my ($self, $line) = @_;

  my @result = ();


  my $length = 0;
  while ($line =~
           m/\G([\x00-\xFF]*?)                   #skip
             (
                $wiki_name_pat
              | $bracket_name_pat
              | $uri_pat
              #| $wiki_fragment_pat
              | $emphasis_pat
              | $swrn_pat
              | $verbatim_pat
              | $block_pat
             )
         /ogx) {

    my $skip = $1;
    my $wiki_name = $3;
    my $bracket_name = $4;
    my $uri = $5;
    #my $wiki_fragment = $6;
    my $emphasis = $6;
    my $swrn = $7;
    my $verbatim = $8;
    my $block = $9;

#    if ($skip) {
    if ($skip ne '') {
      $length += length($skip);
      push(@result, WiKicker::WikiPage::TextNode->new($skip));
    }

    # comment form generate emphasis node.
    if ($emphasis) {
      my $em_length = length($emphasis);
      $length += $em_length;
      $emphasis = substr($emphasis, 2, $em_length - 4);
      my $emphasis_node = WiKicker::WikiPage::EmphasisNode->new;
      $emphasis_node->add($self->parse($emphasis));
      push(@result, $emphasis_node);
      next;
    }
    if ($bracket_name) {
      $length += length($bracket_name);
      push(@result, WiKicker::WikiPage::BracketNameParser
           ->new(wri_factory => $self->{wri_factory})->parse($bracket_name));
      next;
    }
    if ($wiki_name) {
      $length += length($wiki_name);
      push(@result, WiKicker::WikiPage::WriNode->new($wiki_name, $wiki_name, $self->{wri_factory}));
      next;
    }
    if ($uri) {
      $length += length($uri);
      push(@result, WiKicker::WikiPage::WriNode->new($uri, $uri, $self->{wri_factory}));
      next;
    }
#     elsif ($wiki_fragment) {
#       $length += length($wiki_fragment);
#       push(@result, WiKicker::WikiPage::WriNode->new($wiki_fragment));
#     }
    if ($verbatim) {
      $length += length($verbatim);
      my $verbatim_text = $verbatim;
      $verbatim_text =~ s/^====(.*)====$/$1/;
      my $verbatim_node = WiKicker::WikiPage::VerbatimNode->new($verbatim, $verbatim_text);
      push(@result, $verbatim_node);
      next;
    }
    if ($swrn) {
      $length += length($swrn);
      push(@result, WiKicker::WikiPage::WriNode->new($swrn, $swrn, $self->{wri_factory}));
      next;
    }
    if ($block) {
      $length += length($block);
      $block =~ s/^{{(.*)}}$/$1/;
      my $scheme = '';
      if ($block =~ /^([^:]+):(.*)$/) {
        $scheme = $1;
        $block = $2;
      }
      my $block_node = WiKicker::WikiPage::InlineBlockNode->new($scheme);
      $block_node->add($self->parse($block));
      push(@result, $block_node);
      next;
    }
    warn 'Unknown element???';
  }
  if (length($line) > $length) {
    push(@result, WiKicker::WikiPage::TextNode->new(substr($line, $length)));
  }
  return @result;
}

1;
